@@ -161,11 +161,11 @@ class ZendeskDownloader:
         Check to see if end of stream is True this is required because some endpoints return the next endpoint even though all records have been returned.
         If end of stream is False then return either the next_page or after_url depending on which key exists in the response
         """
-
+        if self.base_url == 'https://www.zopim.com/' and self.data.get("count") < self.limit:
+            return None
         if self.data.get("end_of_stream"):
             return None
-        else:
-            return self.data.get("next_page", self.data.get("after_url"))
+        return self.data.get("next_page", self.data.get("after_url"))
 
     def set_endpoint(self):
         """Set `self.endpoint`. 
@@ -220,8 +220,6 @@ class ZendeskDownloader:
         self.set_endpoint()
         if not self.finished:
             self.api_call()
-            responses = self.data
-        else:
-            logging.info("No further call to be made. Closing loop.")
-            responses = []
-        return responses
+            return self.data
+        logging.info("No further call to be made. Closing loop.")
+        return []
